==> kubernetes-model-1.0.60-sources.jar: io/fabric8/openshift/api/model/ProjectRequestBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class ProjectRequestBuilder extends ProjectRequestFluentImpl<ProjectRequestBuilder> implements VisitableBuilder<ProjectRequest,ProjectRequestBuilder>{

    ProjectRequestFluent<?> fluent;
    Boolean validationEnabled;

    public ProjectRequestBuilder(){
            this(true);
    }
    public ProjectRequestBuilder(Boolean validationEnabled){
            this(new ProjectRequest(), validationEnabled);
    }
    public ProjectRequestBuilder(ProjectRequestFluent<?> fluent){
            this(fluent, true);
    }
    public ProjectRequestBuilder(ProjectRequestFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ProjectRequest(), validationEnabled);
    }
    public ProjectRequestBuilder(ProjectRequestFluent<?> fluent,ProjectRequest instance){
            this(fluent, instance, true);
    }
    public ProjectRequestBuilder(ProjectRequestFluent<?> fluent,ProjectRequest instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withApiVersion(instance.getApiVersion()); 
            fluent.withDescription(instance.getDescription()); 
            fluent.withDisplayName(instance.getDisplayName()); 
            fluent.withKind(instance.getKind()); 
            fluent.withMetadata(instance.getMetadata()); 
            this.validationEnabled = validationEnabled; 
    }
    public ProjectRequestBuilder(ProjectRequest instance){
            this(instance,true);
    }
    public ProjectRequestBuilder(ProjectRequest instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withApiVersion(instance.getApiVersion()); 
            this.withDescription(instance.getDescription()); 
            this.withDisplayName(instance.getDisplayName()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.validationEnabled = validationEnabled; 
    }

    public ProjectRequest build(){
            ProjectRequest buildable = new ProjectRequest(fluent.getApiVersion(),fluent.getDescription(),fluent.getDisplayName(),fluent.getKind(),fluent.getMetadata());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ProjectRequestBuilder that = (ProjectRequestBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.64-sources.jar: io/fabric8/openshift/api/model/ProjectRequestBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class ProjectRequestBuilder extends ProjectRequestFluentImpl<ProjectRequestBuilder> implements VisitableBuilder<ProjectRequest,ProjectRequestBuilder>{

    ProjectRequestFluent<?> fluent;
    Boolean validationEnabled;

    public ProjectRequestBuilder(){
            this(true);
    }
    public ProjectRequestBuilder(Boolean validationEnabled){
            this(new ProjectRequest(), validationEnabled);
    }
    public ProjectRequestBuilder(ProjectRequestFluent<?> fluent){
            this(fluent, true);
    }
    public ProjectRequestBuilder(ProjectRequestFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ProjectRequest(), validationEnabled);
    }
    public ProjectRequestBuilder(ProjectRequestFluent<?> fluent,ProjectRequest instance){
            this(fluent, instance, true);
    }
    public ProjectRequestBuilder(ProjectRequestFluent<?> fluent,ProjectRequest instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withApiVersion(instance.getApiVersion()); 
            fluent.withDescription(instance.getDescription()); 
            fluent.withDisplayName(instance.getDisplayName()); 
            fluent.withKind(instance.getKind()); 
            fluent.withMetadata(instance.getMetadata()); 
            this.validationEnabled = validationEnabled; 
    }
    public ProjectRequestBuilder(ProjectRequest instance){
            this(instance,true);
    }
    public ProjectRequestBuilder(ProjectRequest instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withApiVersion(instance.getApiVersion()); 
            this.withDescription(instance.getDescription()); 
            this.withDisplayName(instance.getDisplayName()); 
            this.withKind(instance.getKind()); 
            this.withMetadata(instance.getMetadata()); 
            this.validationEnabled = validationEnabled; 
    }

    public ProjectRequest build(){
            ProjectRequest buildable = new ProjectRequest(fluent.getApiVersion(),fluent.getDescription(),fluent.getDisplayName(),fluent.getKind(),fluent.getMetadata());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ProjectRequestBuilder that = (ProjectRequestBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
